==> hs-statistics-0.4.1.tbz: lib/statistics-0.4.1/register.sh <==
#!/bin/sh

echo 'name: statistics
version: 0.4.1
license: BSD3
copyright: 2009 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
stability:
homepage: http://darcs.serpentine.com/statistics
package-url:
description: This library provides a number of common functions and types useful
             in statistics.  Our focus is on high performance, numerical
             robustness, and use of good algorithms.  Where possible, we provide
             references to the statistical literature.
             .
             The library'\''s facilities can be divided into three broad categories:
             .
             Working with widely used discrete and continuous probability
             distributions.  (There are dozens of exotic distributions in use; we
             focus on the most common.)
             .
             Computing with sample data: quantile estimation, kernel density
             estimation, bootstrap methods, and autocorrelation analysis.
             .
             Random variate generation under several different distributions.
category: Math, Statistics
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules: Statistics.Autocorrelation Statistics.Constants
                 Statistics.Distribution Statistics.Distribution.Binomial
                 Statistics.Distribution.Gamma Statistics.Distribution.Geometric
                 Statistics.Distribution.Exponential
                 Statistics.Distribution.Hypergeometric
                 Statistics.Distribution.Normal Statistics.Distribution.Poisson
                 Statistics.Function Statistics.KernelDensity Statistics.Math
                 Statistics.Quantile Statistics.RandomVariate Statistics.Resampling
                 Statistics.Resampling.Bootstrap Statistics.Sample
                 Statistics.Sample.Powers Statistics.Types
hidden-modules: Statistics.Internal
import-dirs: /usr/local/lib/statistics-0.4.1/ghc-6.10.4
library-dirs: /usr/local/lib/statistics-0.4.1/ghc-6.10.4
hs-libraries: HSstatistics-0.4.1
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.1.0.0 erf-1.0.0.0 mwc-random-0.4.1.1 time-1.1.4
         uvector-0.1.1.0 uvector-algorithms-0.2
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/statistics-0.4.1/html/statistics.haddock
haddock-html: /usr/local/share/doc/statistics-0.4.1/html' | /usr/local/bin/ghc-pkg update -

==> hs-statistics-0.5.1.0.tbz: lib/statistics-0.5.1.0/register.sh <==
#!/bin/sh

echo 'name: statistics
version: 0.5.1.0
license: BSD3
copyright: 2009, 2010 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
stability:
homepage: http://darcs.serpentine.com/statistics
package-url:
description: This library provides a number of common functions and types useful
             in statistics.  Our focus is on high performance, numerical
             robustness, and use of good algorithms.  Where possible, we provide
             references to the statistical literature.
             .
             The library'\''s facilities can be divided into three broad categories:
             .
             Working with widely used discrete and continuous probability
             distributions.  (There are dozens of exotic distributions in use; we
             focus on the most common.)
             .
             Computing with sample data: quantile estimation, kernel density
             estimation, bootstrap methods, and autocorrelation analysis.
             .
             Random variate generation under several different distributions.
category: Math, Statistics
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules: Statistics.Autocorrelation Statistics.Constants
                 Statistics.Distribution Statistics.Distribution.Binomial
                 Statistics.Distribution.Gamma Statistics.Distribution.Geometric
                 Statistics.Distribution.Exponential
                 Statistics.Distribution.Hypergeometric
                 Statistics.Distribution.Normal Statistics.Distribution.Poisson
                 Statistics.Function Statistics.KernelDensity Statistics.Math
                 Statistics.Quantile Statistics.Resampling
                 Statistics.Resampling.Bootstrap Statistics.Sample
                 Statistics.Sample.Powers Statistics.Types
hidden-modules: Statistics.Internal
import-dirs: /usr/local/lib/statistics-0.5.1.0/ghc-6.10.4
library-dirs: /usr/local/lib/statistics-0.5.1.0/ghc-6.10.4
              /usr/local/lib
hs-libraries: HSstatistics-0.5.1.0
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.1.0.0 erf-1.0.0.0 mwc-random-0.5.0.0 primitive-0.3
         time-1.1.4 vector-0.6.0.1 vector-algorithms-0.3.2
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/statistics-0.5.1.0/html/statistics.haddock
haddock-html: /usr/local/share/doc/statistics-0.5.1.0/html' | /usr/local/bin/ghc-pkg update -
